Package: metap
Type: Package
Title: Meta-Analysis of Significance Values
Version: 1.14
Date: 2026-04-29
Authors@R: person("Michael", "Dewey", role = c("aut", "cre"),
    email = "lists@dewey.myzen.co.uk",
    comment = c(ORCID = "0000-0002-7522-3677")
    )
Description: The canonical way to perform meta-analysis involves using effect sizes.
   When they are not available this package provides a number of methods for
   meta-analysis of significance values including the methods of Edgington, Fisher,
   Lancaster, Stouffer, Tippett, and Wilkinson; a number of data-sets to replicate published results;
   and routines for graphical display.
Depends: R (>= 3.5.0)
Imports: lattice,Rdpack (>= 0.7),TFisher,mathjaxr (>=
        2.0-0),qqconf,mutoss
RdMacros: Rdpack,mathjaxr
BuildManual: TRUE
License: GPL-2
LazyLoad: yes
NeedsCompilation: no
Packaged: 2026-04-29 08:42:26 UTC; MichaelUser
Author: Michael Dewey [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7522-3677>)
Maintainer: Michael Dewey <lists@dewey.myzen.co.uk>
Repository: CRAN
Date/Publication: 2026-05-01 13:00:02 UTC
Built: R 4.5.2; ; 2026-05-01 18:15:00 UTC; unix
