export(albatros)
export(allmetap)
export(invchisq)
export(invt)
export(logitp)
export(meanp)
export(meanz)
export(maximump)
export(minimump)
export(plotp)
export(schweder)
export(sumlog)
export(sump)
export(sumz)
export(truncated)
export(two2one)
export(votep)
export(wilkinsonp)
S3method(print,allmetap)
S3method(print,invchisq)
S3method(print,invt)
S3method(print,logitp)
S3method(print,meanp)
S3method(print,meanz)
S3method(print,sumlog)
S3method(print,sump)
S3method(print,sumz)
S3method(print,votep)
S3method(print,maximump)
S3method(print,minimump)
S3method(print,truncated)
S3method(summary,truncated)
S3method(plot,truncated)
S3method(print,wilkinsonp)
S3method(plot,metap)
importFrom("graphics", "abline", "axis", "lines", "mtext", "plot", "text")
importFrom("stats", "binom.test", "coef", "lm", "na.fail", "pbeta", "pchisq",
   "pnorm", "ppoints", "pt", "qbeta", "qchisq", "qnorm", "qqline", "qqplot",
   "qunif", "qt", "sd", "spline")
importFrom("utils", "read.csv")
importFrom("lattice", "xyplot")
importFrom("Rdpack", "reprompt")
importFrom("TFisher", "p.tpm", "stat.tpm")
importFrom("qqconf", "qq_conf_plot")
importFrom("mutoss", "ranktruncated")
import("mathjaxr")
