\newcommand{\nocancel}{Inspection of the distribution of \mjseqn{p}-values is highly recommended as extreme values in opposite directions do not cancel out. See last example. This may not be what you want.}
\newcommand{\plotmethod}{The plot method for class \sQuote{\code{metap}} calls \code{\link{plotp}} on the valid \eqn{p}-values.}
\newcommand{\sigvec}{A vector of significance values}
\newcommand{\ltle}{The values of \mjseqn{p_i} should be such that \mjteqn{0 < p_i\le 1}{0 \lt p_i \le 1}{0 < p_i\le 1} and a warning is given if that is not true. A warning is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
\newcommand{\ltlt}{The values of \mjseqn{p_i} should be such that \mjteqn{0 < p_i < 1}{0 \lt p_i \lt 1}{0 < p_i < 1}and a warning is given if that is not true. A warning is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
\newcommand{\lele}{The values of \mjseqn{p_i} should be such that \mjseqn{0\le p_i\le 1} and a warning is given if that is not true. A warning is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
\newcommand{\logp}{Logical, if TRUE result is returned as log(p)}
\newcommand{\loginput}{Logical, if TRUE the input \mjseqn{p} values are assumed to be logged}