\newcommand{\nocancel}{Inspection of the distribution of \eqn{p}-values is highly recommended as extreme values in opposite directions do not cancel out. See last example. This may not be what you want.}
\newcommand{\plotmethod}{The plot method for class \sQuote{\code{metap}} calls \code{\link{plotp}} on the valid \eqn{p}-values.}
\newcommand{\sigvec}{A vector of significance values}
\newcommand{\ltle}{The values of \eqn{p_i} should be such that \eqn{0<p_i\le 1} and a warning is given if that is not true. An warning is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
\newcommand{\ltlt}{The values of \eqn{p_i} should be such that \eqn{0<p_i<1} and a warning is given if that is not true. An warning is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
\newcommand{\lele}{The values of \eqn{p_i} should be such that \eqn{0\le p_i\le 1} and a warning is given if that is not true. An warnin is given if, possibly as a result of removing illegal values, fewer than #1 values remain and the return values are set to NA.}
